@@ -39,7 +39,6 @@ class SbomChecker:
         doc, err = parse_anything.parse_file(self.file)
         if err:
             logging.error("Document cannot be parsed: %s", err)
-
         return doc
 
     def check_doc_version(self):
@@ -64,7 +63,7 @@ class SbomChecker:
 
     def check_doc_timestamp(self):
         """Check for document timestamp."""
-        if self.doc.creation_info.created is None:
+        if not self.doc.creation_info.created:
             return False
         return True
 
@@ -78,7 +77,7 @@ class SbomChecker:
         """Retrieve SPDX ID of components without names."""
         components_without_names = []
         for package in self.doc.packages:
-            if package.name is None:
+            if not package.name:
                 components_without_names.append(package.spdx_id)
         return components_without_names
 
@@ -86,7 +85,7 @@ class SbomChecker:
         """Retrieve SPDX ID of components without names."""
         components_without_versions = []
         for package in self.doc.packages:
-            if package.version is None:
+            if not package.version:
                 components_without_versions.append(package.name)
         return components_without_versions
 
@@ -94,7 +93,11 @@ class SbomChecker:
         """Retrieve name of components without suppliers."""
         components_without_suppliers = []
         for package in self.doc.packages:
-            if package.supplier is None or "NOASSERTION" in package.supplier.name:
+            if (
+                not package.supplier
+                or "NOASSERTION" in package.supplier.name
+                or not package.supplier.name
+            ):
                 components_without_suppliers.append(package.name)
         return components_without_suppliers
 
@@ -102,7 +105,7 @@ class SbomChecker:
         """Retrieve name of components without identifiers."""
         components_without_identifiers = []
         for package in self.doc.packages:
-            if package.spdx_id is None:
+            if not package.spdx_id:
                 components_without_identifiers.append(package.name)
         return components_without_identifiers
 
